#[non_exhaustive]pub struct AuthConfig {
pub enabled: bool,
pub api_keys: Vec<ApiKeyEntry>,
pub mtls: Option<MtlsConfig>,
pub rate_limit: Option<RateLimitConfig>,
pub oauth: Option<OAuthConfig>,
}Expand description
Authentication configuration.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.enabled: boolMaster switch - when false, all requests are allowed through.
api_keys: Vec<ApiKeyEntry>Bearer token API keys.
mtls: Option<MtlsConfig>mTLS client certificate authentication.
rate_limit: Option<RateLimitConfig>Rate limiting for auth attempts.
oauth: Option<OAuthConfig>OAuth 2.1 JWT bearer token authentication.
Implementations
Sourceimpl AuthConfig
impl AuthConfig
Sourcepub fn with_keys(keys: Vec<ApiKeyEntry>) -> Self
pub fn with_keys(keys: Vec<ApiKeyEntry>) -> Self
Create an enabled auth config with the given API keys.
Sourcepub fn with_rate_limit(self, rate_limit: RateLimitConfig) -> Self
pub fn with_rate_limit(self, rate_limit: RateLimitConfig) -> Self
Set rate limiting on this auth config.
Sourceimpl AuthConfig
impl AuthConfig
Sourcepub fn summary(&self) -> AuthConfigSummary
pub fn summary(&self) -> AuthConfigSummary
Produce a hash-free summary of the auth config for admin endpoints.