DynamicClientCertVerifier

Struct DynamicClientCertVerifier 

pub struct DynamicClientCertVerifier { /* private fields */ }
Stable outer verifier that delegates all TLS verification behavior to the atomically swappable inner verifier.

Implementations

Source

impl DynamicClientCertVerifier

pub fn new(inner: Arc<CrlSet>) -> Self

Construct a new dynamic verifier from a shared CrlSet.