OAuthProxyConfigBuilder

Struct OAuthProxyConfigBuilder 

pub struct OAuthProxyConfigBuilder { /* private fields */ }
Builder for OAuthProxyConfig.

Obtain via OAuthProxyConfig::builder. See the type-level docs on OAuthProxyConfig and in particular the security caveats on OAuthProxyConfig::expose_admin_endpoints.

Implementations

Source

impl OAuthProxyConfigBuilder

pub fn client_secret(self, secret: SecretString) -> Self

Set the upstream OAuth client secret. Omit for public clients.

pub fn introspection_url(self, url: impl Into<String>) -> Self

Configure the upstream RFC 7662 introspection endpoint. Only advertised and reachable when Self::expose_admin_endpoints is also set to true.

pub fn revocation_url(self, url: impl Into<String>) -> Self

Configure the upstream RFC 7009 revocation endpoint. Only advertised and reachable when Self::expose_admin_endpoints is also set to true.

pub const fn expose_admin_endpoints(self, expose: bool) -> Self

Opt in to exposing the /introspect and /revoke admin endpoints and advertising them in the authorization-server metadata document.

Security: see the field-level documentation on OAuthProxyConfig::expose_admin_endpoints for the caveats before enabling this.

pub const fn require_auth_on_admin_endpoints(self, require: bool) -> Self

Require the normal authentication middleware on /introspect and /revoke.

pub fn build(self) -> OAuthProxyConfig

Finalise the builder and return the OAuthProxyConfig.