Module secret

Module secret 

Re-exports for the secrecy crate’s secret-wrapper types. Re-exports of secrecy types for handling sensitive values.

Downstream crates use these to wrap credentials and secrets so that they are not accidentally logged or serialized.

Structs

SecretBox
Wrapper type for values that contains secrets, which attempts to limit accidental exposure and ensure secrets are wiped from memory when dropped. (e.g. passwords, cryptographic keys, access tokens or other credentials)

Traits

ExposeSecret
Expose a reference to an inner secret

Type Aliases

SecretString
Secret string type.